[![Latest PyPI Release](https://img.shields.io/pypi/v/pycartool.svg)](https://pypi.org/project/pycartool/)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/pycartool.svg)](https://pypi.python.org/pypi/pycartool/)
[![Build Status](https://travis-ci.org/Functional-Brain-Mapping-Laboratory/PyCartool.svg?branch=master)](https://travis-ci.org/Functional-Brain-Mapping-Laboratory/PyCartool)
[![codecov](https://codecov.io/gh/vferat/PyCartool/branch/master/graph/badge.svg)](https://codecov.io/gh/vferat/PyCartool)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/38a68c3012224c97827e10e7ca914a52)](https://www.codacy.com/manual/vferat/PyCartool?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=Functional-Brain-Mapping-Laboratory/PyCartool&amp;utm_campaign=Badge_Grade)
[![Documentation Status](https://readthedocs.org/projects/pycartool/badge/?version=latest)](https://pycartool.readthedocs.io/en/latest/?badge=latest)
![License](https://img.shields.io/badge/license-BSD-green.svg)

# PyCartool
A simple open source Python package for I/O between Cartool and python

## About Cartool
Cartool is the EEG analysis software developped at the Functional Brain Mapping Lab (FBMLab), in Geneva, Switzerland. This project was initiated in 1996, and is still actively developped up to these days. It has been entirely programmed by Denis Brunet in C++, and doesn't rely on any other dependency to run.
from [Cartool website](https://sites.google.com/site/cartoolcommunity/about).

![alt text](./img/Cartool.PNG "Cartool")

## Installation

The latest stable version of Pycartool is available through [PyPi](https://pypi.org/project/pycartool/):

`pip install pycartool`

## Documentation

Documentation is available at <https://pycartool.readthedocs.io/en/stable/>

## Contributing to Pycartool

Any contribution is welcome, please let us know by opening an issue!
